===========================
unisos.cryptKeyring Library
===========================

.. contents::
   :depth: 3
..

cryptKeyring Library: Facilities For Front-End Encryption Of Passwds In
Keyring

Support
=======

For support, criticism, comments and questions; please contact the
author/maintainer `Mohsen Banan <http://mohsen.1.banan.byname.net>`__
at: http://mohsen.1.banan.byname.net/contact

Documentation
=============

Part of ByStar Digital Ecosystem http://www.by-star.net.

This module’s primary documentation is in:
http://www.by-star.net/PLPC/180047

Example Usage
=============

::

    from  unisos import symCrypt
    from  unisos import cryptKeyring
